@@ -80,8 +80,15 @@ class PyodbcResource(object):
     def cursor(self):
         return PyodbcCursorContext(self._connection.cursor())
 
+    def callproc(self, procname, *args):
+        cursor = self._connection.cursor()
+        cursor.callproc(procname, *args)
+        return args, PyodbcCursorContext(cursor)
+
     def execute(self, query, *args):
-        return PyodbcCursorContext(self._connection.execute(query, *args))
+        cursor = self._connection.cursor()
+        cursor.execute(query, *args)
+        return PyodbcCursorContext(cursor)
 
     def rollback(self):
         self._connection.rollback()
